@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,15 +22,13 @@
 using namespace KAddressBookGrantlee;
 
 ContactGrantleeGeoObject::ContactGrantleeGeoObject(const KContacts::Geo &geo, QObject *parent)
-    : QObject(parent),
-      mGeo(geo)
+    : QObject(parent)
+    , mGeo(geo)
 {
-
 }
 
 ContactGrantleeGeoObject::~ContactGrantleeGeoObject()
 {
-
 }
 
 float ContactGrantleeGeoObject::latitude() const
